;; Generated package description from embark.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "embark" "1.2.0.20260604.15" "Conveniently act on minibuffer completions" '((emacs "29.1") (compat "31")) :commit "557d933f3a53dbccc750cfbe70c38ad6a17ac866" :authors '(("Omar Antolín Camarena" . "omar@matem.unam.mx")) :maintainer '("Omar Antolín Camarena" . "omar@matem.unam.mx") :keywords '("convenience") :url "https://github.com/oantolin/embark")
